/*
 * soundtouch4c (A wrapper for soundtouch so you can use it in C programs)
 * Copyright (c) 2006-2009 J.A. Roberts Tunney and Anthony Minessale II
 *
 */

#ifndef SOUNDTOUCH4C_H
#define SOUNDTOUCH4C_H
#include <sys/types.h>

#ifdef __cplusplus

#include <stdexcept>
#include <stdio.h>
#include <soundtouch/SoundTouch.h>
using namespace std;
using namespace soundtouch;

extern "C" {

#else 

#define SETTING_USE_AA_FILTER       0
#define SETTING_AA_FILTER_LENGTH    1
#define SETTING_USE_QUICKSEEK       2
#define SETTING_SEQUENCE_MS         3
#define SETTING_SEEKWINDOW_MS       4
#define SETTING_OVERLAP_MS          5

#endif /* #ifdef __cplusplus */

typedef void *soundtouch4c_t;

soundtouch4c_t SoundTouch_construct(void);
void SoundTouch_destruct(soundtouch4c_t st);
void SoundTouch_setRate(soundtouch4c_t st, float newRate);
void SoundTouch_setTempo(soundtouch4c_t st, float newTempo);
void SoundTouch_setRateChange(soundtouch4c_t st, float newRate);
void SoundTouch_setTempoChange(soundtouch4c_t st, float newTempo);
void SoundTouch_setPitch(soundtouch4c_t st, float newPitch);
void SoundTouch_setPitchOctaves(soundtouch4c_t st, float newPitch);
void SoundTouch_setPitchSemiTonesInt(soundtouch4c_t st, int newPitch);
void SoundTouch_setPitchSemiTonesFloat(soundtouch4c_t st, float newPitch);
void SoundTouch_setChannels(soundtouch4c_t st, uint numChannels);
void SoundTouch_setSampleRate(soundtouch4c_t st, uint srate);
void SoundTouch_flush(soundtouch4c_t st);
void SoundTouch_putSamples(soundtouch4c_t st, int16_t *samples, uint numSamples);
void SoundTouch_clear(soundtouch4c_t st);
int SoundTouch_setSetting(soundtouch4c_t st, uint settingId, uint value);
uint SoundTouch_getSetting(soundtouch4c_t st, uint settingId);
uint SoundTouch_numUnprocessedSamples(soundtouch4c_t st);
uint SoundTouch_receiveSamplesEx(soundtouch4c_t st, int16_t *output, uint maxSamples);
uint SoundTouch_receiveSamples(soundtouch4c_t st, uint maxSamples);
uint SoundTouch_numSamples(soundtouch4c_t st);
int SoundTouch_isEmpty(soundtouch4c_t st);

#ifdef __cplusplus
}
#endif

#endif /* #ifndef SOUNDTOUCH4C_H */
 
/** EMACS **
 * Local variables:
 * mode: c++
 * tab-width: 4
 * indent-tabs-mode: t
 * c-basic-offset: 4
 * End:
 */
